@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mediawiki" "2.4.10"
+(define-package "mediawiki" "20250914.2305"
   "Mediawiki frontend."
   '((emacs "28.1"))
   :url "https://github.com/hexmode/mediawiki-el"
-  :commit "cf091148fd8fcf17d81bc5ad556ae18c839f6507"
-  :revdesc "cf091148fd8f"
+  :commit "e0e45e73be527d75127b31746998824115dcf6a5"
+  :revdesc "e0e45e73be52"
   :keywords '("mediawiki" "wikipedia" "network" "wiki")
   :authors '(("Mark A. Hershberger" . "mah@everybody.org"))
   :maintainers '(("Mark A. Hershberger" . "mah@everybody.org")))
